@@ -39,7 +39,7 @@ LEXER_WORDWRAP = settings.LIBPASTE_LEXER_WORDWRAP
 
 
 class NakedHtmlFormatter(HtmlFormatter):
-    def wrap(self, source):
+    def wrap(self, source, outfile=None):
         return self._wrap_code(source)
 
     def _wrap_code(self, source):
