@@ -54,6 +54,7 @@ if config.get('site.admin_mail'):
     ADMINS = (
         ("Xelpaste admins", config.get('site.admin_mail')),
     )
+SERVER_EMAIL = config.get('site.admin_mail_from', 'root@localhost')
 
 
 
@@ -117,6 +118,8 @@ else:
 # Database
 # ========
 
+DEFAULT_AUTO_FIELD = 'django.db.models.AutoField'
+
 _ENGINE_MAP = {
     'sqlite': 'django.db.backends.sqlite3',
     'mysql': 'django.db.backends.mysql',
